============================
SSM AppConfig Storage Helper
============================


.. image:: https://img.shields.io/pypi/v/ssmash.svg
        :target: https://pypi.python.org/pypi/ssmash

.. image:: https://readthedocs.org/projects/ssmash/badge/?version=latest
        :target: https://ssmash.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


SSM AppConfig Storage Helper


* Free software: GNU Affero General Public License v3
* Documentation: https://ssmash.readthedocs.io.

